==> aria2-1.10.6.tar.gz: aria2-1.10.6/src/Exception.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef D_EXCEPTION_H
#define D_EXCEPTION_H

#include "common.h"

#include <cerrno>
#include <string>

#include "SharedHandle.h"

namespace aria2 {

class Exception:public std::exception {
private:
  const char* file_;
  
  int line_;

  int errno_;

  std::string msg_;

  SharedHandle<Exception> cause_;

protected:
  virtual SharedHandle<Exception> copy() const = 0;

public:
  explicit Exception(const char* file, int line, const std::string& msg);

  Exception(const char* file, int line, const std::string& msg,
            const Exception& cause);

  Exception(const char* file, int line, const Exception& e);

  Exception(const char* file, int line, int errnoArg, const std::string& msg);

  virtual ~Exception() throw();

  virtual const char* what() const throw()
  {
    return msg_.c_str();
  }

  std::string stackTrace() const;

  int getErrno() const
  {
    return errno_;
  }
};

} // namespace aria2

#endif // D_EXCEPTION_H

==> aria2-1.15.2.tar.gz: aria2-1.15.2/src/Exception.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef D_EXCEPTION_H
#define D_EXCEPTION_H

#include "common.h"

#include <string>

#include "SharedHandle.h"
#include "error_code.h"

namespace aria2 {

class Exception:public std::exception {
private:
  const char* file_;
  
  int line_;
  // This is low-level system error code, typically errno in Linux.
  int errNum_;

  std::string msg_;
  // This is application-level error code.
  error_code::Value errorCode_;
  // Exception that this object wraps. Normally this cause_ is the
  // root cause of this exception.
  SharedHandle<Exception> cause_;
protected:
  virtual SharedHandle<Exception> copy() const = 0;

public:
  Exception(const char* file, int line, const std::string& msg);

  Exception(const char* file, int line, const std::string& msg,
            error_code::Value errorCode,
            const Exception& cause);
  // errorCode_ is initializedwith cause.errorCode_.
  Exception(const char* file, int line, const std::string& msg,
            const Exception& cause);

  Exception(const char* file, int line, const std::string& msg,
            error_code::Value errorCode);

  Exception(const char* file, int line, int errNum, const std::string& msg);

  Exception(const char* file, int line, int errNum, const std::string& msg,
            error_code::Value errorCode);

  virtual ~Exception() throw();

  virtual const char* what() const throw();

  std::string stackTrace() const;

  int getErrNum() const
  {
    return errNum_;
  }

  error_code::Value getErrorCode() const
  {
    return errorCode_;
  }
};

} // namespace aria2

#endif // D_EXCEPTION_H
